package com.jqtx.windows.common.mq;

import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.jqtx.infrastructure.mq.starter.annotation.MQConsumerComponent;
import com.jqtx.windows.command.GetCreditCommand;
import com.jqtx.windows.common.mq.model.CreditResultModel;
import com.jqtx.windows.component.CreditComponent;
import com.jqtx.windows.component.enums.CreditResultStatusEnum;
import com.jqtx.windows.component.enums.ZNPostUrlEnum;
import com.jqtx.windows.component.model.CreditModel;
import com.jqtx.windows.utils.AbcHttpClient;
import com.jqtx.windows.web.response.CreditDetailResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;

/**
 * @author BlackJokerCJ
 * @Date 2021/2/27
 */
@Slf4j
@MQConsumerComponent(tags = "criusCreditResult", topic = "$mq.creditTopic")
public class CreditResultListener extends AbstractMQConsumerHandler<CreditResultModel> {

    @Autowired
    private CreditComponent creditComponent;

    @Autowired
    private AbcHttpClient abcHttpClient;

    @Autowired
    private GetCreditCommand getCreditCommand;
    @Override
    public Class getClazz() {
        return CreditResultModel.class;
    }

    @Override
    public void run(CreditResultModel creditResultModel) throws Exception {
        CreditModel creditModel = creditComponent.getByOrderNo(creditResultModel.getOrderNo());
        if(ObjectUtil.isNull(creditModel) || !CreditResultStatusEnum.INIT.name().equals(creditModel.getCreditResult())){
            return;
        }
        CreditModel update =  new CreditModel();
        CreditDetailResponse creditDetailResponse = new CreditDetailResponse();
        if ("YES".equalsIgnoreCase(creditResultModel.getCreditStatus())) {
            update.setCreditResult(CreditResultStatusEnum.PASS.getCode());
            //通过
            creditDetailResponse.setStatus("1");
            creditDetailResponse.setApprovalAmount(creditResultModel.getCreditAmt().toEngineeringString());
        }
        if ("RETRIAL".equalsIgnoreCase(creditResultModel.getCreditStatus())) {
            update.setCreditResult(CreditResultStatusEnum.INIT.getCode());
        }
        if ("REJECT".equalsIgnoreCase(creditResultModel.getCreditStatus())) {
            update.setCreditResult(CreditResultStatusEnum.REFUSED.getCode());
            creditDetailResponse.setStatus("2");
        }
        creditComponent.updateByOrderNo(creditModel.getOrderNo(),update);
        creditDetailResponse.setRemark(creditResultModel.getMemo());
        creditDetailResponse.setTransNo(IdUtil.fastSimpleUUID());
        abcHttpClient.postRequest(JSON.toJSONString(creditDetailResponse), ZNPostUrlEnum.CREDIT_CALL.getCode());
    }
}

